	subroutine where (x, y, f)
c
c  returns current:
c    x - pen x position in inches from last origin
c    y - pen y position in inches from last origin
c    f - plot sizing factor (see subroutine factor)
c

	common /cqpbnf/ xold, yold, fac, ires
	save   /cqpbnf/
	real            xold, yold, fac
	integer                          ires

	x = xold/fac
	y = yold/fac
	f = fac

	return
	end
